#!/bin/sh

#  process Acid Rain Data
#   bc = basecase = day specific
#   bl = baseline = generic
#

# tx_osd_fy18a_midlokilns - 15Aug2013 afs.midlokilns_2011_baseline_to_be_capped_v1 & control.midlokilns_cap, MKJ 14Aug2013
# tx_osd_fy18b_midlokilns_grown - 12Sep2013 afs.midlokilns_2018_nox_emissions.RPOlcp, MKJ 30Aug2013, SAS grown instead of cntlem
# tx_osd_fy18b_midlokilns_grown - 05Jun2014 afs.midlokilns_2018_nox_emissions.RPOlcp, MKJ 05Jun2014, kiln consent decree
# tx_osd_fy17a_midlokilns_grown - 20May2015 afs.midlokilns_2017_nox_emissions.RPOlcp, MKJ 15May2015, kiln consent decree; Same as 2018 file
# tx_osd_fy17b_midlokilns       - 28Apr2016 afs.midlokilns_2017_nox_emissions.RPOlcp, MKJ 11Mar 2016
# tx_osd_fy17c_midlokilns       - 27Sep2016 afs.midlokilns_2017_nox_emissions.RPOlcp.v2, MKJ 26Sep2016, 17.6 tpd
# tx_osd_fy20a_midlokilns       - 17Jul2018 afs.midlothian_kiln_2020_agreed_orders, MKJ 6July2018, 10.0356 tpd
# tx_osd_fy20a_midlokilns_hc    - 24Oct2018 afs.midlothian_kiln_2020_HARD_CAP, MKJ 8Oct2018, 17.6 tpd
# fy20b_midlokilns_hc  - 3Jan2019  afs.midlothian_kiln_2020_HARD_CAP_trial, MKJ 13Dec2018, 17.6 tpd
# fy20c_midlokilns_hc - 28Feb2019  afs.midlothian_kiln_2020_HARD_CAP_trial_v2, KW 28Feb2019, 17.6 tpd
# fy20c_midlokilnsv3 - 18Mar2019  afs.midlothian_kiln_2020_HARD_CAP_trial_v3, KW 18Mar2019, 17.18 tpd
# fy20c_midlokilnsv4 - 01Apr2019  afs.midlothian_kiln_2020_HARD_CAP_trial_v4, KW 01Apr2019, 15.12 tpd
# fy20a_b12it - 16Jul2019 afs.midlothian_kiln_2020_agreed_orders_b12, KW 16Jul2019, 15.12 tpd
#

 USER_PATH=/ei/point/rpo_eps3/userin
 export USER_PATH

 today=`date +%y%b%d`
 PT_PATH=/ei/point/rpo_eps3
 export PT_PATH

 EPS3_PATH=/usr/local/pub/eps3/src
 export EPS3_PATH

 for county_switch in 10co
  do

  case $county_switch in
   '8co')    county_group=hgb_8co ;;
   'no8co')  county_group=no_hgb_8co ;;
   '10co')    county_group=dfw_10co ;;
   'no10co')  county_group=no_dfw_10co ;;
   'no18co') county_group=no_h_d_18co ;;
  esac

 run_type=tx_osd
 yyX=20a_b12it_midlokilns
 #control=control.midlokilns_cap
 scenario=tx_osd_fy${yyX}_${county_group}
 subd=fy20a_b12it

 #grid=conus_36km
 grid=na_12km

 tmprof_xref=tmprl.xref.tx_osd_fy2020c
 tmprof=tmprl.profs.tx_osd_fy2020c

 ugrid=${grid}_egu_${county_group} # forces Midlokilns elevated

 for spec in cb6p
  do

  #cb05 splitfac=`get_file "/ei/point/EPS3/chmspl/emscvt/splitfac.cb05.2008_v3b.pt.all.12Jul10"`
  #cb05 chmprof_xref=`get_file "/ei/point/EPS3/chmspl/spec_xref/xref.voc.eps3f.2008_v3b.pt.all.12Jul10"`

 case $spec in
  'cb4')   fac_v=2005v3a_2004v4d.pt.all ;;
  'cb05')  fac_v=2006_v6a.pt.all ;;
  's99')   fac_v=2000v15c.pt.all ;;
  'cb6')   fac_v=2006_v7a.pt.all;;
  'cb6p') prof=gspro_2020_v3a_w_HECT_cap_n_trade.16Jul2018
          xref=gsref_2016_v3a.02Jul2018
          conv=gscnv_2016_v3a.02Jul2018 ;;
 esac

 for yymmdd in \
  200615 \

 do
 
 afsin=afs.tx_osd.fy${yyX}.$county_group
 
master_uin=$USER_PATH/$grid/userin.$spec.YYMMDD.$ugrid
 temp_uin=$USER_PATH/$grid/userin.$spec.$yymmdd.$ugrid
 dow=`date -d $yymmdd | awk '{print $1}'`
 sed "s/DOW/$dow/g" $master_uin > $temp_uin
 dd=`echo $yymmdd | cut -c5-`
 Mmm=`date -d $yymmdd | awk '{print $2}'`
 yyyy=`date -d $yymmdd | awk '{print $NF}'`
 perl -pi -e "s/ DD Mmm YYYY/ $dd $Mmm $yyyy/" $temp_uin
 perl -pi -e "s/YYMMDD/$yymmdd/" $temp_uin 

 echo
 echo "today  yymmdd  grid scenario afsin ugrid dow dd Mmm YYYY"
 echo $today  $yymmdd  $grid $scenario $afsin $ugrid $dow $dd $Mmm $yyyy

 cd $PT_PATH/prepnt/$run_type
  run.prepnt.$run_type.sh $today $yymmdd $grid $spec $run_type $scenario $afsin $ugrid

 #12Sep2013#cd $PT_PATH/cntlem/$run_type
 #12Sep2013# run.cntlem.$run_type.sh $today $yymmdd $grid $spec $run_type $scenario $ugrid $scenario $control "prepnt"

 cd $PT_PATH/spcems/$run_type
  run.spcems.$run_type.sh $today $yymmdd $grid $spec $run_type $scenario $ugrid $prof $xref $conv 
  #run.spcems.$run_type.sh $today $yymmdd $grid $spec $run_type $scenario $ugrid $prof $xref $conv 'cntlem'

 cd $PT_PATH/tmprl/$run_type
  run.tmprl.$run_type.sh  $today $yymmdd $grid $spec $run_type $scenario $tmprof_xref $tmprof $ugrid

 cd $PT_PATH/pstpnt/$run_type
  run.pstpnt.$run_type.sh  $today $yymmdd $grid $spec $run_type $scenario $ugrid

 cd $PT_PATH/pigems/$run_type
  run.pigems.$run_type.sh  $today $yymmdd $grid $spec $run_type $scenario $ugrid
 
# Replace yymmdd 
  rename $yymmdd OSD $PT_PATH/*/$run_type/*$scenario.$today    
  
 #rm $temp_uin

 #Move output files to subdirectory
 for t in prepnt spcems tmprl pstpnt pigems
  do
 
   if [ ! -d  $PT_PATH/$t/$run_type/$subd ]; then
    mkdir -p $PT_PATH/$t/$run_type/$subd
   fi
   mv $PT_PATH/$t/$run_type/*$scenario.$today  $PT_PATH/$t/$run_type/$subd
   ls -l $PT_PATH/$t/$run_type/$subd/*$scenario.$today
  done #t


 done
 done
done
exit
